@@ -5,20 +5,19 @@
 
 from __future__ import print_function
 
-import plac
-import base64
-import json
-import time
 import pprint
+
+import plac
 import requests
 
+
 @plac.annotations(
-    server_url=('URL of Produce & Publish API)', 'option', 's'),
+    server_url=("URL of Produce & Publish API)", "option", "s"),
 )
-def converter_versions(server_url='http://localhost:6543'):
-    if server_url.endswith('/'):
+def converter_versions(server_url="http://localhost:6543"):
+    if server_url.endswith("/"):
         server_url = server_url[:-1]
-    result = requests.get(server_url + '/converter-versions')
+    result = requests.get(server_url + "/converter-versions")
     if result.status_code == 200:
         pprint.pprint(result.json())
     else:
@@ -28,5 +27,6 @@ def converter_versions(server_url='http://localhost:6543'):
 def main():
     plac.call(converter_versions)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
